]> git.mxchange.org Git - friendica.git/commitdiff
change default ajax interval to 40 seconds
authorfriendica <info@friendica.com>
Tue, 13 Dec 2011 01:10:19 +0000 (17:10 -0800)
committerfriendica <info@friendica.com>
Tue, 13 Dec 2011 01:10:19 +0000 (17:10 -0800)
boot.php
mod/settings.php

index 2553642fcf1bf2360cc53dce5f56726e1f8971c5..b02b0be982886afbaf14d373b091c8ba4de9da71 100644 (file)
--- a/boot.php
+++ b/boot.php
@@ -422,9 +422,9 @@ class App {
        } 
 
        function init_pagehead() {
-               $interval = ((local_user()) ? get_pconfig(local_user(),'system','update_interval') : 30000);
+               $interval = ((local_user()) ? get_pconfig(local_user(),'system','update_interval') : 40000);
                if($interval < 10000)
-                       $interval = 30000;
+                       $interval = 40000;
 
                $this->page['title'] = $this->config['sitename'];
                $tpl = file_get_contents('view/head.tpl');
index e88e50a05f92a0430dfa4fb90521b858115a5ba7..18e2d8ae6be1821874539bfd9be1e9330d4293c9 100644 (file)
@@ -227,7 +227,7 @@ function settings_post(&$a) {
        $browser_update   = ((x($_POST,'browser_update')) ? intval($_POST['browser_update']) : 0);
        $browser_update   = $browser_update * 1000;
        if($browser_update < 10000)
-               $browser_update = 30000;
+               $browser_update = 40000;
 
 
        $allow_location   = (((x($_POST,'allow_location')) && (intval($_POST['allow_location']) == 1)) ? 1: 0);
@@ -625,8 +625,8 @@ function settings_content(&$a) {
        $suggestme = get_pconfig(local_user(), 'system','suggestme');
        $suggestme = (($suggestme===false)?0:$suggestme); // default if not set: 0
 
-       $browser_update = get_pconfig(local_user(), 'system','update_interval');
-       $browser_update = (($browser_update===false)? 30 : $browser_update / 1000); // default if not set: 30 seconds
+       $browser_update = intval(get_pconfig(local_user(), 'system','update_interval'));
+       $browser_update = (($browser_update===false)? 40 : $browser_update / 1000); // default if not set: 40 seconds
        
        if(! strlen($a->user['timezone']))
                $timezone = date_default_timezone_get();